@@ -9,20 +9,6 @@
 #ifndef _FUSE_H_
 #define _FUSE_H_
 
-/** @file
- *
- * This file defines the library interface of FUSE
- *
- * IMPORTANT: you should define FUSE_USE_VERSION before including this
- * header.  To use the newest API define it to 26 (recommended for any
- * new application), to use the old API define it to 21 (default) 22
- * or 25, to use the even older 1.X API define it to 11.
- */
-
-#ifndef FUSE_USE_VERSION
-#define FUSE_USE_VERSION 21
-#endif
-
 #include "extern_c.h"
 #include "fuse_common.h"
 
@@ -475,9 +461,10 @@ struct fuse_operations
    *
    * Introduced in version 2.9
    */
-  int (*write_buf) (const fuse_file_info_t *ffi,
-                    struct fuse_bufvec     *buf,
-                    off_t                   off);
+  int (*write) (const fuse_file_info_t *ffi,
+                const char             *data,
+                size_t                  size,
+                off_t                   off);
 
   /** Store data from an open file in a buffer
    *
@@ -495,10 +482,10 @@ struct fuse_operations
    *
    * Introduced in version 2.9
    */
-  int (*read_buf) (const fuse_file_info_t  *ffi,
-                   struct fuse_bufvec     **bufp,
-                   size_t                   size,
-                   off_t                    off);
+  int (*read)(const fuse_file_info_t *ffi,
+              char                   *buf,
+              size_t                  size,
+              off_t                   off);
   /**
    * Perform BSD file locking operation
    *
@@ -552,6 +539,16 @@ struct fuse_operations
                              off_t                   offset_out,
                              size_t                  size,
                              int                     flags);
+
+  ssize_t (*setupmapping)(uint64_t *fh_,
+                          uint64_t  foffset_,
+                          uint64_t  len_,
+                          uint64_t  flags_,
+                          uint64_t  moffset_);
+
+  int (*removemapping)();
+  int (*syncfs)();
+  int (*tmpfile)(const char *, mode_t, fuse_file_info_t *);
 };
 
 /** Extra context that may be needed by some filesystems
@@ -640,7 +637,10 @@ void fuse_destroy(struct fuse *f);
  */
 void fuse_exit(struct fuse *f);
 
-int fuse_config_num_threads(const struct fuse *fuse_);
+int fuse_config_read_thread_count(const struct fuse *f);
+int fuse_config_process_thread_count(const struct fuse *f);
+int fuse_config_process_thread_queue_depth(const struct fuse *f);
+const char* fuse_config_pin_threads(const struct fuse *f);
 
 /**
  * FUSE event loop with multiple threads
@@ -729,101 +729,6 @@ struct fuse_fs;
  * fuse_fs_releasedir and fuse_fs_statfs, which return 0.
  */
 
-int fuse_fs_getattr(struct fuse_fs  *fs,
-                    const char      *path,
-                    struct stat     *buf,
-                    fuse_timeouts_t *timeout);
-
-int fuse_fs_fgetattr(struct fuse_fs   *fs,
-                     struct stat      *buf,
-                     fuse_file_info_t *fi,
-                     fuse_timeouts_t  *timeout);
-
-int fuse_fs_rename(struct fuse_fs *fs, const char *oldpath,
-                   const char *newpath);
-int fuse_fs_unlink(struct fuse_fs *fs, const char *path);
-int fuse_fs_rmdir(struct fuse_fs *fs, const char *path);
-int fuse_fs_symlink(struct fuse_fs *fs,
-                    const char *linkname,
-		    const char *path,
-                    struct stat *st,
-                    fuse_timeouts_t *timeouts);
-int fuse_fs_link(struct fuse_fs *fs,
-                 const char *oldpath,
-                 const char *newpath,
-                 struct stat *st,
-                 fuse_timeouts_t *timeouts);
-int fuse_fs_release(struct fuse_fs *fs,
-                    fuse_file_info_t *fi);
-int fuse_fs_open(struct fuse_fs *fs, const char *path,
-                 fuse_file_info_t *fi);
-int fuse_fs_read_buf(struct fuse_fs *fs,
-                     struct fuse_bufvec **bufp, size_t size, off_t off,
-                     fuse_file_info_t *fi);
-int fuse_fs_write_buf(struct fuse_fs *fs,
-                      struct fuse_bufvec *buf, off_t off,
-                      fuse_file_info_t *fi);
-int fuse_fs_fsync(struct fuse_fs *fs, int datasync,
-                  fuse_file_info_t *fi);
-int fuse_fs_flush(struct fuse_fs *fs,
-                  fuse_file_info_t *fi);
-int fuse_fs_statfs(struct fuse_fs *fs, const char *path, struct statvfs *buf);
-int fuse_fs_opendir(struct fuse_fs *fs, const char *path,
-                    fuse_file_info_t *fi);
-int fuse_fs_readdir(struct fuse_fs        *fs,
-                    fuse_file_info_t *fi,
-                    fuse_dirents_t        *buf);
-int fuse_fs_fsyncdir(struct fuse_fs *fs, int datasync,
-                     fuse_file_info_t *fi);
-int fuse_fs_releasedir(struct fuse_fs *fs,
-                       fuse_file_info_t *fi);
-int fuse_fs_create(struct fuse_fs *fs, const char *path, mode_t mode,
-                   fuse_file_info_t *fi);
-int fuse_fs_lock(struct fuse_fs *fs,
-                 fuse_file_info_t *fi, int cmd, struct flock *lock);
-int fuse_fs_flock(struct fuse_fs *fs,
-                  fuse_file_info_t *fi, int op);
-int fuse_fs_chmod(struct fuse_fs *fs, const char *path, mode_t mode);
-int fuse_fs_chown(struct fuse_fs *fs, const char *path, uid_t uid, gid_t gid);
-int fuse_fs_truncate(struct fuse_fs *fs, const char *path, off_t size);
-int fuse_fs_ftruncate(struct fuse_fs *fs, off_t size,
-                      fuse_file_info_t *fi);
-int fuse_fs_utimens(struct fuse_fs *fs, const char *path,
-                    const struct timespec tv[2]);
-int fuse_fs_access(struct fuse_fs *fs, const char *path, int mask);
-int fuse_fs_readlink(struct fuse_fs *fs, const char *path, char *buf,
-                     size_t len);
-int fuse_fs_mknod(struct fuse_fs *fs, const char *path, mode_t mode,
-                  dev_t rdev);
-int fuse_fs_mkdir(struct fuse_fs *fs, const char *path, mode_t mode);
-int fuse_fs_setxattr(struct fuse_fs *fs, const char *path, const char *name,
-                     const char *value, size_t size, int flags);
-int fuse_fs_getxattr(struct fuse_fs *fs, const char *path, const char *name,
-                     char *value, size_t size);
-int fuse_fs_listxattr(struct fuse_fs *fs, const char *path, char *list,
-                      size_t size);
-int fuse_fs_removexattr(struct fuse_fs *fs, const char *path,
-                        const char *name);
-int fuse_fs_bmap(struct fuse_fs *fs, const char *path, size_t blocksize,
-                 uint64_t *idx);
-int fuse_fs_ioctl(struct fuse_fs *fs, unsigned long cmd, void *arg,
-                  fuse_file_info_t *fi, unsigned int flags,
-                  void *data, uint32_t *out_bufsz);
-int fuse_fs_poll(struct fuse_fs *fs,
-                 fuse_file_info_t *fi, fuse_pollhandle_t *ph,
-                 unsigned *reventsp);
-int fuse_fs_fallocate(struct fuse_fs *fs, int mode,
-                      off_t offset, off_t length, fuse_file_info_t *fi);
-void fuse_fs_init(struct fuse_fs *fs, struct fuse_conn_info *conn);
-void fuse_fs_destroy(struct fuse_fs *fs);
-
-int fuse_fs_prepare_hide(struct fuse_fs *fs, const char *path, uint64_t *fh);
-int fuse_fs_free_hide(struct fuse_fs *fs, uint64_t fh);
-ssize_t fuse_fs_copy_file_range(struct fuse_fs *fs,
-                                fuse_file_info_t *fi_in, off_t off_in,
-                                fuse_file_info_t *fi_out, off_t off_out,
-                                size_t len, int flags);
-
 int fuse_notify_poll(fuse_pollhandle_t *ph);
 
 /**
@@ -856,12 +761,6 @@ struct fuse *fuse_setup(int argc, char *argv[],
 /** This is the part of fuse_main() after the event loop */
 void fuse_teardown(struct fuse *fuse, char *mountpoint);
 
-/** Read a single command.  If none are read, return NULL */
-struct fuse_cmd *fuse_read_cmd(struct fuse *f);
-
-/** Process a single command */
-void fuse_process_cmd(struct fuse *f, struct fuse_cmd *cmd);
-
 /** Multi threaded event loop, which calls the custom command
     processor function */
 int fuse_loop_mt_proc(struct fuse *f, fuse_processor_t proc, void *data);
@@ -876,6 +775,10 @@ void fuse_set_getcontext_func(struct fuse_context *(*func)(void));
 /** Get session from fuse object */
 struct fuse_session *fuse_get_session(struct fuse *f);
 
+void fuse_gc1();
+void fuse_gc();
+void fuse_invalidate_all_nodes();
+
 EXTERN_C_END
 
 #endif /* _FUSE_H_ */
