@@ -10,24 +10,25 @@
 
 #include "fuse.h"
 #include "fuse_lowlevel.h"
+#include "fuse_msgbuf.h"
+
+#include "extern_c.h"
 
 struct fuse_chan;
 struct fuse_ll;
 
 struct fuse_session
 {
-  struct fuse_session_ops op;
+  int (*receive_buf)(struct fuse_session *se,
+                     fuse_msgbuf_t       *msgbuf);
 
-  int (*receive_buf)(struct fuse_session *se, struct fuse_buf *buf,
-                     struct fuse_chan **chp);
+  void (*process_buf)(struct fuse_session *se,
+                      const fuse_msgbuf_t *msgbuf);
 
-  void (*process_buf)(void *data, const struct fuse_buf *buf,
-                      struct fuse_chan *ch);
-
-  void *data;
+  void (*destroy)(void *data);
 
+  struct fuse_ll *f;
   volatile int exited;
-
   struct fuse_chan *ch;
 };
 
@@ -46,8 +47,7 @@ struct fuse_notify_req
   void (*reply)(struct fuse_notify_req *,
                 fuse_req_t,
                 uint64_t,
-                const void *,
-                const struct fuse_buf *);
+                const void *);
   struct fuse_notify_req *next;
   struct fuse_notify_req *prev;
 };
@@ -58,18 +58,12 @@ struct fuse_ll
   int no_remote_posix_lock;
   int no_remote_flock;
   int big_writes;
-  int splice_write;
-  int splice_move;
-  int splice_read;
-  int no_splice_write;
-  int no_splice_move;
-  int no_splice_read;
   struct fuse_lowlevel_ops op;
-  int got_init;
   void *userdata;
   uid_t owner;
   struct fuse_conn_info conn;
   pthread_mutex_t lock;
+  int got_init;
   int got_destroy;
   pthread_key_t pipe_key;
   int broken_splice_nonblock;
@@ -84,6 +78,8 @@ struct fuse_cmd
   struct fuse_chan *ch;
 };
 
+EXTERN_C_BEGIN
+
 struct fuse *fuse_new_common(struct fuse_chan *ch, struct fuse_args *args,
 			     const struct fuse_operations *op,
 			     size_t op_size);
@@ -111,3 +107,5 @@ struct fuse *fuse_setup_common(int argc, char *argv[],
 			       int *fd);
 
 int fuse_start_thread(pthread_t *thread_id, void *(*func)(void *), void *arg);
+
+EXTERN_C_END
