@@ -18,19 +18,25 @@
 
 #include "fh.hpp"
 
+#include <cstdint>
 #include <string>
+#include <mutex>
 
 
 class FileInfo : public FH
 {
 public:
-  FileInfo(const int   fd_,
-           const char *fusepath_)
+  FileInfo(int const   fd_,
+           char const *fusepath_,
+           bool const  direct_io_)
     : FH(fusepath_),
-      fd(fd_)
+      fd(fd_),
+      direct_io(direct_io_)
   {
   }
 
 public:
   int fd;
+  uint32_t direct_io:1;
+  std::mutex mutex;
 };
