@@ -23,12 +23,12 @@
 #include "fs_statvfs_cache.hpp"
 #include "statvfs_util.hpp"
 
-#include <stdint.h>
-
+#include <cstdint>
 #include <string>
 
 using std::string;
 
+
 namespace fs
 {
   int
