@@ -28,11 +28,11 @@ namespace fs
   movefile(const Policy::Create &policy,
            const Branches::CPtr &branches,
            const std::string    &fusepath,
-           int                  *origfd);
+           int                   origfd);
 
   int
   movefile_as_root(const Policy::Create &policy,
                    const Branches::CPtr &branches,
                    const std::string    &fusepath,
-                   int                  *origfd);
+                   int                   origfd);
 }
