@@ -19,43 +19,39 @@
 #include "fs_info.hpp"
 #include "fs_path.hpp"
 #include "policy.hpp"
+#include "policies.hpp"
 #include "policy_error.hpp"
-#include "rwlock.hpp"
+#include "strvec.hpp"
 
 #include <string>
-#include <vector>
 
 using std::string;
-using std::vector;
 
 namespace all
 {
   static
   int
-  create(const BranchVec &branches_,
-         vector<string>  *paths_)
+  create(const Branches::CPtr &branches_,
+         StrVec               *paths_)
   {
     int rv;
     int error;
     fs::info_t info;
-    const Branch *branch;
 
     error = ENOENT;
-    for(size_t i = 0, ei = branches_.size(); i != ei; i++)
+    for(auto &branch : *branches_)
       {
-        branch = &branches_[i];
-
-        if(branch->ro_or_nc())
+        if(branch.ro_or_nc())
           error_and_continue(error,EROFS);
-        rv = fs::info(branch->path,&info);
+        rv = fs::info(branch.path,&info);
         if(rv == -1)
           error_and_continue(error,ENOENT);
         if(info.readonly)
           error_and_continue(error,EROFS);
-        if(info.spaceavail < branch->minfreespace())
+        if(info.spaceavail < branch.minfreespace())
           error_and_continue(error,ENOSPC);
 
-        paths_->push_back(branch->path);
+        paths_->push_back(branch.path);
       }
 
     if(paths_->empty())
@@ -63,26 +59,28 @@ namespace all
 
     return 0;
   }
-
-  static
-  int
-  create(const Branches &branches_,
-         vector<string> *paths_)
-  {
-    rwlock::ReadGuard guard(branches_.lock);
-
-    return all::create(branches_.vec,paths_);
-  }
 }
 
 int
-Policy::Func::all(const Category  type_,
-                  const Branches &branches_,
-                  const char     *fusepath_,
-                  vector<string> *paths_)
+Policy::All::Action::operator()(const Branches::CPtr &branches_,
+                                const char           *fusepath_,
+                                StrVec               *paths_) const
 {
-  if(type_ == Category::CREATE)
-    return all::create(branches_,paths_);
+  return Policies::Action::epall(branches_,fusepath_,paths_);
+}
 
-  return Policy::Func::epall(type_,branches_,fusepath_,paths_);
+int
+Policy::All::Create::operator()(const Branches::CPtr &branches_,
+                                const char           *fusepath_,
+                                StrVec               *paths_) const
+{
+  return ::all::create(branches_,paths_);
+}
+
+int
+Policy::All::Search::operator()(const Branches::CPtr &branches_,
+                                const char           *fusepath_,
+                                StrVec               *paths_) const
+{
+  return Policies::Search::epall(branches_,fusepath_,paths_);
 }
