@@ -15,24 +15,54 @@
 */
 
 #include "errno.hpp"
+#include "policies.hpp"
 #include "policy.hpp"
+#include "policy_eprand.hpp"
 
 #include <algorithm>
-#include <string>
-#include <vector>
-
-using std::string;
-using std::vector;
 
 int
-Policy::Func::eprand(const Category  type_,
-                     const Branches &branches_,
-                     const char     *fusepath_,
-                     vector<string> *paths_)
+Policy::EPRand::Action::operator()(const Branches::CPtr &branches_,
+                                   const char           *fusepath_,
+                                   StrVec               *paths_) const
 {
   int rv;
 
-  rv = Policy::Func::epall(type_,branches_,fusepath_,paths_);
+  rv = Policies::Action::epall(branches_,fusepath_,paths_);
+  if(rv == 0)
+    {
+      std::random_shuffle(paths_->begin(),paths_->end());
+      paths_->resize(1);
+    }
+
+  return rv;
+}
+
+int
+Policy::EPRand::Create::operator()(const Branches::CPtr &branches_,
+                                   const char           *fusepath_,
+                                   StrVec               *paths_) const
+{
+  int rv;
+
+  rv = Policies::Create::epall(branches_,fusepath_,paths_);
+  if(rv == 0)
+    {
+      std::random_shuffle(paths_->begin(),paths_->end());
+      paths_->resize(1);
+    }
+
+  return rv;
+}
+
+int
+Policy::EPRand::Search::operator()(const Branches::CPtr &branches_,
+                                   const char           *fusepath_,
+                                   StrVec               *paths_) const
+{
+  int rv;
+
+  rv = Policies::Search::epall(branches_,fusepath_,paths_);
   if(rv == 0)
     {
       std::random_shuffle(paths_->begin(),paths_->end());
