@@ -18,9 +18,11 @@
 #include "fs_exists.hpp"
 #include "fs_info.hpp"
 #include "fs_path.hpp"
+#include "policies.hpp"
 #include "policy.hpp"
 #include "policy_error.hpp"
-#include "rwlock.hpp"
+#include "policy_lus.hpp"
+#include "strvec.hpp"
 
 #include <limits>
 #include <string>
@@ -33,37 +35,34 @@ namespace lus
 {
   static
   int
-  create(const BranchVec &branches_,
-         vector<string>  *paths_)
+  create(const Branches::CPtr &branches_,
+         StrVec               *paths_)
   {
     int rv;
     int error;
     uint64_t lus;
     fs::info_t info;
-    const Branch *branch;
     const string *basepath;
 
     error = ENOENT;
     lus = std::numeric_limits<uint64_t>::max();
     basepath = NULL;
-    for(size_t i = 0, ei = branches_.size(); i != ei; i++)
+    for(auto &branch : *branches_)
       {
-        branch = &branches_[i];
-
-        if(branch->ro_or_nc())
+        if(branch.ro_or_nc())
           error_and_continue(error,EROFS);
-        rv = fs::info(branch->path,&info);
+        rv = fs::info(branch.path,&info);
         if(rv == -1)
           error_and_continue(error,ENOENT);
         if(info.readonly)
           error_and_continue(error,EROFS);
-        if(info.spaceavail < branch->minfreespace())
+        if(info.spaceavail < branch.minfreespace())
           error_and_continue(error,ENOSPC);
         if(info.spaceused >= lus)
           continue;
 
         lus      = info.spaceused;
-        basepath = &branch->path;
+        basepath = &branch.path;
       }
 
     if(basepath == NULL)
@@ -73,26 +72,28 @@ namespace lus
 
     return 0;
   }
-
-  static
-  int
-  create(const Branches &branches_,
-         vector<string> *paths_)
-  {
-    rwlock::ReadGuard guard(branches_.lock);
-
-    return lus::create(branches_.vec,paths_);
-  }
 }
 
 int
-Policy::Func::lus(const Category  type_,
-                  const Branches &branches_,
-                  const char     *fusepath_,
-                  vector<string> *paths_)
+Policy::LUS::Action::operator()(const Branches::CPtr &branches_,
+                                const char           *fusepath_,
+                                StrVec               *paths_) const
 {
-  if(type_ == Category::CREATE)
-    return lus::create(branches_,paths_);
+  return Policies::Action::eplus(branches_,fusepath_,paths_);
+}
 
-  return Policy::Func::eplus(type_,branches_,fusepath_,paths_);
+int
+Policy::LUS::Create::operator()(const Branches::CPtr &branches_,
+                                const char           *fusepath_,
+                                StrVec               *paths_) const
+{
+  return ::lus::create(branches_,paths_);
+}
+
+int
+Policy::LUS::Search::operator()(const Branches::CPtr &branches_,
+                                const char           *fusepath_,
+                                StrVec               *paths_) const
+{
+  return Policies::Search::eplus(branches_,fusepath_,paths_);
 }
