@@ -19,8 +19,8 @@
 namespace resources
 {
   int reset_umask(void);
-  int maxout_rlimit(const int resource_);
+  int maxout_rlimit(const int resource);
   int maxout_rlimit_nofile(void);
   int maxout_rlimit_fsize(void);
-  int setpriority(const int prio_);
+  int setpriority(const int prio);
 }
