@@ -26,15 +26,19 @@
 
 
 static uint64_t G_SEED;
-static RND      G_RND;
 
-RND::RND()
+__attribute__((constructor))
+static
+void
+_constructor()
 {
   struct timeval tv;
 
   gettimeofday(&tv,NULL);
 
-  G_SEED = ((tv.tv_sec << 32) | (tv.tv_usec));
+  G_SEED   = tv.tv_sec;
+  G_SEED <<= 32;
+  G_SEED  |= tv.tv_usec;
 }
 
 uint64_t
