@@ -31,6 +31,15 @@ namespace str
         const char                delimiter,
         std::vector<std::string> *result);
 
+  void
+  split(const char            *str,
+        const char             delimiter,
+        std::set<std::string> *result);
+  void
+  split(const std::string     &str,
+        const char             delimiter,
+        std::set<std::string> *result);
+
   void
   rsplit1(const std::string        &str,
           const char                delimiter,
