@@ -16,10 +16,10 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
+#include <cstdint>
 #include <string>
 
 #include <inttypes.h>
-#include <stdint.h>
 #include <stdio.h>
 
 namespace str
